@@ -30,6 +30,8 @@ extern "C" {
 #define cut_take_printf(format, ...)                                    \
     cut_test_context_take_printf(get_current_test_context(),            \
                                  (format), __VA_ARGS__)
+#define cut_take_string_array(strings)                                  \
+    cut_test_context_take_string_array(get_current_test_context(), (strings))
 
 #define cut_take_diff(from, to)                                         \
     cut_take_string(cut_diff_readable(from, to))
