@@ -32,7 +32,8 @@
 
 #include "cut-main.h"
 
-#include "cut-runner.h"
+#include "cut-listener.h"
+#include "cut-test-runner.h"
 #include "cut-test-suite.h"
 #include "cut-ui.h"
 #include "cut-module-factory.h"
@@ -44,10 +45,13 @@ static gchar *test_directory = NULL;
 static gchar *source_directory = NULL;
 static gchar **test_case_names = NULL;
 static gchar **test_names = NULL;
+static gchar **exclude_files = NULL;
+static gchar **exclude_dirs = NULL;
 static CutOrder test_case_order = CUT_ORDER_NONE_SPECIFIED;
 static gboolean use_multi_thread = FALSE;
 static GList *factories = NULL;
 static CutContractor *contractor = NULL;
+static gchar **original_argv = NULL;
 
 static gboolean
 print_version (const gchar *option_name, const gchar *value,
@@ -93,6 +97,10 @@ static const GOptionEntry option_entries[] =
      N_("Run test cases with multi-thread"), NULL},
     {"test-case-order", 0, 0, G_OPTION_ARG_CALLBACK, parse_test_case_order,
      N_("Sort test case by. Default is 'none'."), "[none|name|name-desc]"},
+    {"exclude-file", 0, 0, G_OPTION_ARG_STRING_ARRAY, &exclude_files,
+     N_("Skip files"), "FILE_NAME"},
+    {"exclude-dir", 0, 0, G_OPTION_ARG_STRING_ARRAY, &exclude_dirs,
+     N_("Skip directories"), "DIRECTORY_NAME"},
     {NULL}
 };
 
@@ -109,6 +117,8 @@ cut_init (int *argc, char ***argv)
 
     initialized = TRUE;
 
+    original_argv = g_strdupv(*argv);
+
     bindtextdomain(GETTEXT_PACKAGE, LOCALEDIR);
     bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
     textdomain(GETTEXT_PACKAGE);
@@ -200,22 +210,25 @@ cut_quit (void)
     initialized = FALSE;
 }
 
-CutRunner *
-cut_create_runner (void)
+CutRunContext *
+cut_create_run_context (void)
 {
-    CutRunner *runner;
+    CutRunContext *run_context;
 
-    runner = cut_runner_new();
+    run_context = cut_test_runner_new();
 
-    cut_runner_set_test_directory(runner, test_directory);
+    cut_run_context_set_test_directory(run_context, test_directory);
     if (source_directory)
-        cut_runner_set_source_directory(runner, source_directory);
-    cut_runner_set_multi_thread(runner, use_multi_thread);
-    cut_runner_set_target_test_case_names(runner, test_case_names);
-    cut_runner_set_target_test_names(runner, test_names);
-    cut_runner_set_test_case_order(runner, test_case_order);
+        cut_run_context_set_source_directory(run_context, source_directory);
+    cut_run_context_set_multi_thread(run_context, use_multi_thread);
+    cut_run_context_set_exclude_files(run_context, (const gchar **)exclude_files);
+    cut_run_context_set_exclude_directories(run_context, (const gchar **)exclude_dirs);
+    cut_run_context_set_target_test_case_names(run_context, test_case_names);
+    cut_run_context_set_target_test_names(run_context, test_names);
+    cut_run_context_set_test_case_order(run_context, test_case_order);
+    cut_run_context_set_command_line_args(run_context, original_argv);
 
-    return runner;
+    return run_context;
 }
 
 static GList *
@@ -233,24 +246,24 @@ create_listeners (void)
 }
 
 static void
-add_listeners (CutRunner *runner, GList *listeners)
+add_listeners (CutRunContext *run_context, GList *listeners)
 {
     GList *node;
 
     for (node = listeners; node; node = g_list_next(node)) {
         CutListener *listener = CUT_LISTENER(node->data);
-        cut_runner_add_listener(runner, listener);
+        cut_run_context_add_listener(run_context, listener);
     }
 }
 
 static void
-remove_listeners (CutRunner *runner, GList *listeners)
+remove_listeners (CutRunContext *run_context, GList *listeners)
 {
     GList *node;
 
     for (node = listeners; node; node = g_list_next(node)) {
         CutListener *listener = CUT_LISTENER(node->data);
-        cut_runner_remove_listener(runner, listener);
+        cut_run_context_remove_listener(run_context, listener);
         g_object_unref(listener);
     }
 }
@@ -272,7 +285,7 @@ get_cut_ui (GList *listeners)
 }
 
 gboolean
-cut_run_runner (CutRunner *runner)
+cut_start_run_context (CutRunContext *run_context)
 {
     gboolean success;
     GList *listeners;
@@ -284,15 +297,15 @@ cut_run_runner (CutRunner *runner)
     }
 
     listeners = create_listeners();
-    add_listeners(runner, listeners);
+    add_listeners(run_context, listeners);
 
     ui = get_cut_ui(listeners);
     if (ui)
-        success = cut_ui_run(ui, runner);
+        success = cut_ui_run(ui, run_context);
     else
-        success = cut_runner_run(runner);
+        success = cut_run_context_start(run_context);
 
-    remove_listeners(runner, listeners);
+    remove_listeners(run_context, listeners);
     g_list_free(listeners);
 
     return success;
@@ -301,12 +314,12 @@ cut_run_runner (CutRunner *runner)
 gboolean
 cut_run (void)
 {
-    CutRunner *runner;
+    CutRunContext *run_context;
     gboolean success = TRUE;
 
-    runner = cut_create_runner();
-    success = cut_run_runner(runner);
-    g_object_unref(runner);
+    run_context = cut_create_run_context();
+    success = cut_start_run_context(run_context);
+    g_object_unref(run_context);
 
     return success;
 }
