@@ -24,18 +24,18 @@
 #  error "don't include cutter.h with test runner program!"
 #endif
 
-#include <cutter/cut-runner.h>
+#include <cutter/cut-test-runner.h>
 #include <cutter/cut-test-suite.h>
 
 G_BEGIN_DECLS
 
-void          cut_init              (int *argc, char ***argv);
-void          cut_quit              (void);
+void          cut_init               (int *argc, char ***argv);
+void          cut_quit               (void);
 
-gboolean      cut_run               (void);
+gboolean      cut_run                (void);
 
-CutRunner    *cut_create_runner     (void);
-gboolean      cut_run_runner        (CutRunner    *runner);
+CutRunContext *cut_create_run_context(void);
+gboolean       cut_start_run_context (CutRunContext *run_context);
 
 G_END_DECLS
 
