@@ -2,20 +2,18 @@
 /*
  *  Copyright (C) 2007  Kouhei Sutou <kou@cozmixng.org>
  *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Lesser General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
+ *  This library is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU Lesser General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
  *
  *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
- *  License along with this program; if not, write to the
- *  Free Software Foundation, Inc., 59 Temple Place, Suite 330,
- *  Boston, MA  02111-1307  USA
+ *  You should have received a copy of the GNU Lesser General Public License
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -54,20 +52,6 @@ struct _CutModuleFactoryClass
 
 GType        cut_module_factory_get_type    (void) G_GNUC_CONST;
 
-void         cut_module_factory_init        (void);
-void         cut_module_factory_quit        (void);
-
-const gchar *cut_module_factory_get_default_module_dir   (void);
-void         cut_module_factory_set_default_module_dir   (const gchar *dir);
-
-void         cut_module_factory_load        (const gchar *dir,
-                                             const gchar *type);
-void         cut_module_factory_load_all    (const gchar *base_dir);
-void         cut_module_factory_unload      (void);
-GList       *cut_module_factory_get_names   (const gchar *type);
-gboolean     cut_module_factory_exist_module(const gchar *type,
-                                             const gchar *name);
-
 CutModuleFactory *cut_module_factory_new    (const gchar *type,
                                              const gchar *name,
                                              const gchar *first_property,
