@@ -24,7 +24,8 @@
 
 G_BEGIN_DECLS
 
-typedef struct _CutRunner          CutRunner;
+typedef struct _CutRunContext      CutRunContext;
+typedef struct _CutTestRunner      CutTestRunner;
 typedef struct _CutListener        CutListener;
 typedef struct _CutTestSuite       CutTestSuite;
 typedef struct _CutTestCase        CutTestCase;
