@@ -33,6 +33,7 @@
 #include "cut-test-suite.h"
 #include "cut-test-result.h"
 #include "cut-process.h"
+#include "cut-utils.h"
 
 #define CUT_TEST_CONTEXT_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), CUT_TYPE_TEST_CONTEXT, CutTestContextPrivate))
 
@@ -48,6 +49,7 @@ struct _CutTestContextPrivate
     GList *taken_strings;
     GList *taken_string_arrays;
     GList *taken_objects;
+    GList *taken_errors;
     gpointer user_data;
     GDestroyNotify user_data_destroy_notify;
     GList *processes;
@@ -124,6 +126,9 @@ cut_test_context_init (CutTestContext *context)
     priv->taken_strings = NULL;
     priv->taken_string_arrays = NULL;
 
+    priv->taken_objects = NULL;
+    priv->taken_errors = NULL;
+
     priv->user_data = NULL;
     priv->user_data_destroy_notify = NULL;
 
@@ -172,6 +177,12 @@ dispose (GObject *object)
         priv->taken_objects = NULL;
     }
 
+    if (priv->taken_errors) {
+        g_list_foreach(priv->taken_errors, (GFunc)g_error_free, NULL);
+        g_list_free(priv->taken_errors);
+        priv->taken_errors = NULL;
+    }
+
     if (priv->user_data && priv->user_data_destroy_notify)
         priv->user_data_destroy_notify(priv->user_data);
     priv->user_data = NULL;
@@ -238,6 +249,12 @@ cut_test_context_new (CutTestSuite *test_suite, CutTestCase *test_case,
                         NULL);
 }
 
+CutTestContext *
+cut_test_context_new_empty (void)
+{
+    return cut_test_context_new(NULL, NULL, NULL);
+}
+
 CutTestSuite *
 cut_test_context_get_test_suite (CutTestContext *context)
 {
@@ -425,6 +442,12 @@ cut_test_context_register_result (CutTestContext *context,
     g_object_unref(result);
 }
 
+void
+cut_test_context_set_failed (CutTestContext *context, gboolean failed)
+{
+    CUT_TEST_CONTEXT_GET_PRIVATE(context)->failed = failed;
+}
+
 gboolean
 cut_test_context_is_failed (CutTestContext *context)
 {
@@ -487,6 +510,20 @@ cut_test_context_take_g_object (CutTestContext *context,
     return object;
 }
 
+const GError *
+cut_test_context_take_g_error (CutTestContext *context, GError *error)
+{
+    CutTestContextPrivate *priv;
+    GError *taken_error;
+
+    priv = CUT_TEST_CONTEXT_GET_PRIVATE(context);
+    taken_error = g_error_copy(error);
+    g_error_free(error);
+    priv->taken_errors = g_list_prepend(priv->taken_errors, taken_error);
+
+    return taken_error;
+}
+
 int
 cut_test_context_trap_fork (CutTestContext *context,
                             const gchar *function_name,
@@ -516,14 +553,16 @@ int
 cut_test_context_wait_process (CutTestContext *context,
                                int pid, unsigned int timeout)
 {
-    int status = EXIT_SUCCESS;
+    int exit_status = EXIT_SUCCESS;
     CutProcess *process;
 
     process = get_process_from_pid(context, pid);
     if (process) {
+        int process_status;
         const gchar *xml;
 
-        status = WEXITSTATUS(cut_process_wait(process, timeout));
+        process_status = cut_process_wait(process, timeout);
+        exit_status = WEXITSTATUS(process_status);
         xml = cut_process_get_result_from_child(process);
         if (xml)
             xml = strstr(xml, "<result>");
@@ -536,7 +575,7 @@ cut_test_context_wait_process (CutTestContext *context,
             if (next_result_xml)
                 result_xml_length = next_result_xml - xml;
 
-            result = cut_test_result_new_from_xml(xml, result_xml_length);
+            result = cut_test_result_new_from_xml(xml, result_xml_length, NULL);
             if (result) {
                 cut_test_context_emit_signal(context, result);
                 g_object_unref(result);
@@ -549,7 +588,7 @@ cut_test_context_wait_process (CutTestContext *context,
         }
     }
 
-    return EXIT_SUCCESS;
+    return exit_status;
 }
 
 const char *
@@ -591,6 +630,43 @@ cut_test_context_is_multi_thread (CutTestContext *context)
     return CUT_TEST_CONTEXT_GET_PRIVATE(context)->is_multi_thread;
 }
 
+gchar *
+cut_test_context_to_xml (CutTestContext *context)
+{
+    GString *string;
+
+    string = g_string_new(NULL);
+    cut_test_context_to_xml_string(context, string, 0);
+    return g_string_free(string, FALSE);
+}
+
+void
+cut_test_context_to_xml_string (CutTestContext *context, GString *string,
+                                guint indent)
+{
+    CutTestContextPrivate *priv;
+
+    priv = CUT_TEST_CONTEXT_GET_PRIVATE(context);
+
+    cut_utils_append_indent(string, indent);
+    g_string_append(string, "<test-context>\n");
+
+    if (priv->test_suite)
+        cut_test_to_xml_string(CUT_TEST(priv->test_suite), string, indent + 2);
+    if (priv->test_case)
+        cut_test_to_xml_string(CUT_TEST(priv->test_case), string, indent + 2);
+    if (priv->test)
+        cut_test_to_xml_string(priv->test, string, indent + 2);
+
+    cut_utils_append_xml_element_with_boolean_value(string, indent + 2,
+                                                    "failed", priv->failed);
+
+
+    cut_utils_append_indent(string, indent);
+    g_string_append(string, "</test-context>\n");
+}
+
+
 /*
 vi:ts=4:nowrap:ai:expandtab:sw=4
 */
