@@ -56,6 +56,7 @@ GType        cut_test_context_get_type  (void) G_GNUC_CONST;
 CutTestContext  *cut_test_context_new (CutTestSuite *test_suite,
                                        CutTestCase  *test_case,
                                        CutTest      *test);
+CutTestContext  *cut_test_context_new_empty (void);
 
 CutTestSuite *cut_test_context_get_test_suite (CutTestContext *context);
 void          cut_test_context_set_test_suite (CutTestContext *context,
@@ -77,6 +78,8 @@ void          cut_test_context_set_user_data  (CutTestContext *context,
                                                gpointer        user_data,
                                                GDestroyNotify  notify);
 
+void          cut_test_context_set_failed     (CutTestContext *context,
+                                               gboolean        failed);
 gboolean      cut_test_context_is_failed      (CutTestContext *context);
 
 void          cut_test_context_set_jump       (CutTestContext *context,
@@ -84,6 +87,11 @@ void          cut_test_context_set_jump       (CutTestContext *context,
 void          cut_test_context_emit_signal    (CutTestContext *context,
                                                CutTestResult  *result);
 
+gchar        *cut_test_context_to_xml         (CutTestContext *context);
+void          cut_test_context_to_xml_string  (CutTestContext *context,
+                                               GString        *string,
+                                               guint           indent);
+
 G_END_DECLS
 
 #endif /* __CUT_TEST_CONTEXT_H__ */
