@@ -30,7 +30,8 @@
 #include "cut-test.h"
 #include "cut-test-case.h"
 #include "cut-test-suite.h"
-#include "cut-xml-parser.h"
+#include "cut-stream-parser.h"
+#include "cut-utils.h"
 
 #define CUT_TEST_RESULT_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), CUT_TYPE_TEST_RESULT, CutTestResultPrivate))
 
@@ -355,9 +356,45 @@ cut_test_result_new (CutTestResultStatus status,
 }
 
 CutTestResult *
-cut_test_result_new_from_xml (const gchar *xml, gssize length)
+cut_test_result_new_empty (void)
 {
-    return cut_xml_parse_test_result_xml(xml, length);
+    return cut_test_result_new(CUT_TEST_RESULT_SUCCESS,
+                               NULL, NULL, NULL,
+                               NULL, NULL,
+                               NULL, NULL, 0);
+}
+
+static void
+collect_result (CutStreamParser *parser, CutTestResult *result,
+                gpointer user_data)
+{
+    CutTestResult **result_store = (CutTestResult **)user_data;
+
+    *result_store = result;
+    g_object_ref(*result_store);
+}
+
+CutTestResult *
+cut_test_result_new_from_xml (const gchar *xml, gssize length, GError **error)
+{
+    CutStreamParser *parser;
+    CutTestResult *result = NULL;
+
+    if (!xml)
+        return NULL;
+
+    parser = cut_test_result_parser_new();
+    g_signal_connect(parser, "result",
+                     G_CALLBACK(collect_result), (gpointer)(&result));
+
+    cut_stream_parser_parse(parser, xml, length, error);
+
+    g_signal_handlers_disconnect_by_func(parser,
+                                         collect_result,
+                                         (gpointer)&result);
+    g_object_unref(parser);
+
+    return result;
 }
 
 CutTestResultStatus
@@ -418,6 +455,12 @@ cut_test_result_get_test_case_name (CutTestResult *result)
     return NULL;
 }
 
+CutTestSuite *
+cut_test_result_get_test_suite (CutTestResult *result)
+{
+    return CUT_TEST_RESULT_GET_PRIVATE(result)->test_suite;
+}
+
 const gchar *
 cut_test_result_get_test_suite_name (CutTestResult *result)
 {
@@ -464,26 +507,14 @@ cut_test_result_get_elapsed (CutTestResult *result)
     return CUT_TEST_RESULT_GET_PRIVATE(result)->elapsed;
 }
 
-static void
-append_indent (GString *string, guint indent)
+gchar *
+cut_test_result_to_xml (CutTestResult *result)
 {
-    guint i;
-    for (i = 0; i < indent; i++)
-        g_string_append_c(string, ' ');
+    GString *string;
 
-}
-
-static void
-append_element_with_value (GString *string, guint indent, const gchar *element_name, const gchar *value)
-{
-    gchar *escaped;
-    append_indent(string, indent);
-    escaped = g_markup_printf_escaped("<%s>%s</%s>\n",
-                                      element_name,
-                                      value,
-                                      element_name);
-    g_string_append(string, escaped);
-    g_free(escaped);
+    string = g_string_new(NULL);
+    cut_test_result_to_xml_string(result, string, 0);
+    return g_string_free(string, FALSE);
 }
 
 static const gchar *
@@ -505,6 +536,9 @@ result_status_to_name (CutTestResultStatus status)
       case CUT_TEST_RESULT_NOTIFICATION:
         return "notification";
         break;
+      case CUT_TEST_RESULT_OMISSION:
+        return "omission";
+        break;
       default:
         return "unknown status";
         break;
@@ -512,7 +546,8 @@ result_status_to_name (CutTestResultStatus status)
 }
 
 static void
-append_element_valist (GString *string, guint indent, const gchar *element_name, va_list var_args)
+append_element_valist (GString *string, guint indent,
+                       const gchar *element_name, va_list var_args)
 {
     const gchar *name;
 
@@ -521,7 +556,7 @@ append_element_valist (GString *string, guint indent, const gchar *element_name,
     while (name) {
         const gchar *value = va_arg(var_args, gchar *);
         if (value)
-            append_element_with_value(string, indent, name, value);
+            cut_utils_append_xml_element_with_value(string, indent, name, value);
         name = va_arg(var_args, gchar *);
     }
 }
@@ -535,37 +570,53 @@ append_element_with_children (GString *string, guint indent,
     va_list var_args;
 
     escaped = g_markup_escape_text(element_name, -1);
-    append_indent(string, indent);
+    cut_utils_append_indent(string, indent);
     g_string_append_printf(string, "<%s>\n", escaped);
 
     va_start(var_args, first_child_element);
     append_element_valist(string, indent + 2, first_child_element, var_args);
     va_end(var_args);
 
-    append_indent(string, indent);
+    cut_utils_append_indent(string, indent);
     g_string_append_printf(string, "</%s>\n", escaped);
     g_free(escaped);
 }
 
 static void
-append_backtrace_to_string (GString *string, CutTestResult *result)
+append_backtrace_to_string (GString *string, CutTestResult *result, guint indent)
 {
-    gchar *line_string, *info_string;
+    CutTestResultPrivate *priv;
+    gchar *line_string = NULL;
+    gchar *info_string = NULL;
 
-    line_string = g_strdup_printf("%d", cut_test_result_get_line(result));
-    info_string = g_strdup_printf("%s()", cut_test_result_get_function_name(result));
+    priv = CUT_TEST_RESULT_GET_PRIVATE(result);
+    if (priv->filename == NULL && priv->function_name == NULL)
+        return;
 
-    append_element_with_children(string, 4, "backtrace",
-                                 "file", cut_test_result_get_filename(result),
+    if (priv->line > 0)
+        line_string = g_strdup_printf("%d", priv->line);
+    if (priv->function_name)
+        info_string = g_strdup_printf("%s()", priv->function_name);
+
+    cut_utils_append_indent(string, indent);
+    g_string_append(string, "<backtrace>\n");
+    append_element_with_children(string, indent + 2, "entry",
+                                 "file", priv->filename,
                                  "line", line_string,
                                  "info", info_string,
                                  NULL);
-    g_free(line_string);
-    g_free(info_string);
+    cut_utils_append_indent(string, indent);
+    g_string_append(string, "</backtrace>\n");
+
+    if (line_string)
+        g_free(line_string);
+    if (info_string)
+        g_free(info_string);
 }
 
 static void
-append_test_result_to_string (GString *string, CutTestResult *result)
+append_test_result_to_string (GString *string, CutTestResult *result,
+                              guint indent)
 {
     CutTestResultStatus status;
     gchar *elapsed_string;
@@ -575,78 +626,38 @@ append_test_result_to_string (GString *string, CutTestResult *result)
     message = cut_test_result_get_message(result);
     status = cut_test_result_get_status(result);
 
-    append_element_with_value(string, 4, "status", result_status_to_name(status));
+    cut_utils_append_xml_element_with_value(string, indent, "status",
+                                            result_status_to_name(status));
     if (message)
-        append_element_with_value(string, 4, "detail", message);
+        cut_utils_append_xml_element_with_value(string, indent,
+                                                "detail", message);
     if (status != CUT_TEST_RESULT_SUCCESS)
-        append_backtrace_to_string(string, result);
-    append_element_with_value(string, 4, "elapsed", elapsed_string);
+        append_backtrace_to_string(string, result, indent);
+    cut_utils_append_xml_element_with_value(string, indent, "elapsed",
+                                            elapsed_string);
     g_free(elapsed_string);
 }
 
-static void
-append_attribute (const gchar *key, const gchar *value, GString *string)
+void
+cut_test_result_to_xml_string (CutTestResult *result, GString *string,
+                               guint indent)
 {
-    guint indent = 6;
+    CutTestCase *test_case;
+    CutTest *test;
 
-    if (!strcmp(key, "description"))
-        return;
+    cut_utils_append_indent(string, indent);
+    g_string_append(string, "<result>\n");
 
-    append_indent(string, indent);
-    g_string_append(string, "<option>\n");
+    test_case = cut_test_result_get_test_case(result);
+    if (test_case)
+        cut_test_to_xml_string(CUT_TEST(test_case), string, indent + 2);
+    test = cut_test_result_get_test(result);
+    if (test)
+        cut_test_to_xml_string(test, string, indent + 2);
+    append_test_result_to_string(string, result, indent + 2);
 
-    append_element_with_value(string, indent + 2, "name", key);
-    append_element_with_value(string, indent + 2, "value", value);
-
-    append_indent(string, indent);
-    g_string_append(string, "</option>\n");
-}
-
-static void
-append_test_info_to_string (GString *string, const gchar *element_name, CutTest *test)
-{
-    gchar *escaped;
-    const gchar *description, *name;
-    guint indent = 4;
-    GHashTable *attributes;
-
-    if (!test)
-        return;
-
-    escaped = g_markup_escape_text(element_name, -1);
-    append_indent(string, indent);
-    g_string_append_printf(string, "<%s>\n", escaped);
-
-    name = cut_test_get_name(test);
-    if (name)
-        append_element_with_value(string, indent + 2, "name", name);
-
-    description = cut_test_get_description(test);
-    if (description)
-        append_element_with_value(string, indent + 2, "description", description);
-
-    attributes = (GHashTable *)cut_test_get_attributes(test);
-    if (attributes)
-        g_hash_table_foreach(attributes, (GHFunc)append_attribute, string);
-
-    append_indent(string, indent);
-    g_string_append_printf(string, "</%s>\n", escaped);
-    g_free(escaped);
-}
-
-gchar *
-cut_test_result_to_xml (CutTestResult *result)
-{
-    GString *xml = g_string_new("");
-
-    g_string_append(xml, "  <result>\n");
-    append_test_info_to_string(xml, "test-case",
-                               CUT_TEST(cut_test_result_get_test_case(result)));
-    append_test_info_to_string(xml, "test", cut_test_result_get_test(result));
-    append_test_result_to_string(xml, result);
-    g_string_append(xml, "  </result>\n");
-
-    return g_string_free(xml, FALSE);
+    cut_utils_append_indent(string, indent);
+    g_string_append(string, "</result>\n");
 }
 
 const gchar *
@@ -720,7 +731,7 @@ cut_test_result_set_test_case (CutTestResult *result, CutTestCase *test_case)
 }
 
 void
-cut_test_result_set_test_suite (CutTestResult *result, CutTestCase *test_suite)
+cut_test_result_set_test_suite (CutTestResult *result, CutTestSuite *test_suite)
 {
     CutTestResultPrivate *priv = CUT_TEST_RESULT_GET_PRIVATE(result);
 
