@@ -28,15 +28,13 @@
 #include <glib.h>
 
 #include <setjmp.h>
-#define __USE_GNU
 #include <signal.h>
-#undef __USE_GNU
 
 #include "cut-test-suite.h"
 
 #include "cut-test.h"
 #include "cut-test-case.h"
-#include "cut-runner.h"
+#include "cut-run-context.h"
 #include "cut-utils.h"
 #include "cut-marshalers.h"
 #include "cut-test-result.h"
@@ -50,7 +48,7 @@ enum
 };
 
 static jmp_buf jump_buffer;
-static gchar *stack_trace = NULL;
+static gchar *backtrace = NULL;
 
 static gint cut_test_suite_signals[LAST_SIGNAL] = {0};
 
@@ -99,14 +97,16 @@ cut_test_suite_init (CutTestSuite *test_suite)
 CutTestSuite *
 cut_test_suite_new (void)
 {
-    return g_object_new(CUT_TYPE_TEST_SUITE, NULL);
+    return g_object_new(CUT_TYPE_TEST_SUITE,
+                        "element-name", "test-suite",
+                        NULL);
 }
 
 typedef struct _RunTestInfo
 {
     CutTestSuite *test_suite;
     CutTestCase *test_case;
-    CutRunner *runner;
+    CutRunContext *run_context;
     gchar **test_names;
 } RunTestInfo;
 
@@ -116,22 +116,22 @@ run (gpointer data)
     RunTestInfo *info = data;
     CutTestSuite *test_suite;
     CutTestCase *test_case;
-    CutRunner *runner;
+    CutRunContext *run_context;
     gchar **test_names;
     gboolean success;
 
     test_suite = info->test_suite;
     test_case = info->test_case;
-    runner = info->runner;
+    run_context = info->run_context;
     test_names = info->test_names;
 
     g_signal_emit_by_name(test_suite, "start-test-case", test_case);
-    success = cut_test_case_run_with_filter(test_case, runner, test_names);
+    success = cut_test_case_run_with_filter(test_case, run_context, (const gchar**)test_names);
     g_signal_emit_by_name(test_suite, "complete-test-case", test_case);
 
     g_object_unref(test_suite);
     g_object_unref(test_case);
-    g_object_unref(runner);
+    g_object_unref(run_context);
     g_strfreev(test_names);
     g_free(info);
 
@@ -140,19 +140,19 @@ run (gpointer data)
 
 static void
 run_with_thread (CutTestSuite *test_suite, CutTestCase *test_case,
-                 CutRunner *runner, gchar **test_names,
+                 CutRunContext *run_context, const gchar **test_names,
                  gboolean try_thread, GList **threads, gboolean *success)
 {
     RunTestInfo *info;
     gboolean need_no_thread_run = TRUE;
 
-    if (cut_runner_is_canceled(runner))
+    if (cut_run_context_is_canceled(run_context))
         return;
 
     info = g_new0(RunTestInfo, 1);
     info->test_suite = g_object_ref(test_suite);
     info->test_case = g_object_ref(test_case);
-    info->runner = g_object_ref(runner);
+    info->run_context = g_object_ref(run_context);
     info->test_names = g_strdupv((gchar **)test_names);
 
     if (try_thread) {
@@ -176,7 +176,7 @@ run_with_thread (CutTestSuite *test_suite, CutTestCase *test_case,
 }
 
 static void
-read_stack_trace (int in_fd)
+read_backtrace (int in_fd)
 {
     GRegex *regex;
     GString *buffer;
@@ -192,17 +192,17 @@ read_stack_trace (int in_fd)
                         G_REGEX_MULTILINE | G_REGEX_DOTALL,
                         G_REGEX_MATCH_NEWLINE_ANY, NULL);
     if (regex) {
-        stack_trace = g_regex_replace(regex, buffer->str, buffer->len, 0,
-                                      "", 0, NULL);
+        backtrace = g_regex_replace(regex, buffer->str, buffer->len, 0,
+                                    "", 0, NULL);
         g_regex_unref(regex);
         g_string_free(buffer, TRUE);
     } else {
-        stack_trace = g_string_free(buffer, FALSE);
+        backtrace = g_string_free(buffer, FALSE);
     }
 }
 
 static void
-collect_stack_trace (void)
+collect_backtrace (void)
 {
     int fds[2];
     FILE *original_stdout, *pseudo_stdout;
@@ -225,7 +225,7 @@ collect_stack_trace (void)
     stdout = original_stdout;
     fclose(pseudo_stdout);
 
-    read_stack_trace(fds[0]);
+    read_backtrace(fds[0]);
 
     close(fds[0]);
     close(fds[1]);
@@ -234,15 +234,15 @@ collect_stack_trace (void)
 static void
 i_will_be_back_handler (int signum)
 {
-    g_free(stack_trace);
-    stack_trace = NULL;
-    collect_stack_trace();
+    g_free(backtrace);
+    backtrace = NULL;
+    collect_backtrace();
     longjmp(jump_buffer, signum);
 }
 
 static void
 emit_ready_signal (CutTestSuite *test_suite, GList *test_cases,
-                   gchar **test_names)
+                   const gchar **test_names)
 {
     GList *node;
     guint n_test_cases, n_tests;
@@ -261,35 +261,43 @@ emit_ready_signal (CutTestSuite *test_suite, GList *test_cases,
 }
 
 static gboolean
-cut_test_suite_run_test_cases (CutTestSuite *test_suite, CutRunner *runner,
-                               GList *test_cases, gchar **test_names)
+cut_test_suite_run_test_cases (CutTestSuite *test_suite, CutRunContext *run_context,
+                               GList *test_cases, const gchar **test_names)
 {
     GList *node, *threads = NULL;
     GList *sorted_test_cases;
     gboolean try_thread;
     gboolean all_success = TRUE;
     gint signum;
-    sighandler_t previous_segv_handler, previous_int_handler;
+    struct sigaction i_will_be_back_action;
+    struct sigaction previous_segv_action, previous_int_action;
+    gboolean set_segv_action = TRUE;
+    gboolean set_int_action = TRUE;
 
     sorted_test_cases = g_list_copy(test_cases);
-    sorted_test_cases = cut_runner_sort_test_cases(runner, sorted_test_cases);
-    previous_segv_handler = signal(SIGSEGV, i_will_be_back_handler);
-    previous_int_handler = signal(SIGINT, i_will_be_back_handler);
+    sorted_test_cases = cut_run_context_sort_test_cases(run_context, sorted_test_cases);
+    i_will_be_back_action.sa_handler = i_will_be_back_handler;
+    sigemptyset(&i_will_be_back_action.sa_mask);
+    i_will_be_back_action.sa_flags = 0;
+    if (sigaction(SIGSEGV, &i_will_be_back_action, &previous_segv_action) == -1)
+        set_segv_action = FALSE;
+    if (sigaction(SIGINT, &i_will_be_back_action, &previous_int_action) == -1)
+        set_int_action = FALSE;
     signum = setjmp(jump_buffer);
     switch (signum) {
       case 0:
-        cut_runner_prepare_test_suite(runner, test_suite);
+        cut_run_context_prepare_test_suite(run_context, test_suite);
         emit_ready_signal(test_suite, sorted_test_cases, test_names);
         g_signal_emit_by_name(CUT_TEST(test_suite), "start");
 
-        try_thread = cut_runner_get_multi_thread(runner);
+        try_thread = cut_run_context_get_multi_thread(run_context);
         for (node = sorted_test_cases; node; node = g_list_next(node)) {
             CutTestCase *test_case = node->data;
 
             if (!test_case)
                 continue;
             if (CUT_IS_TEST_CASE(test_case)) {
-                run_with_thread(test_suite, test_case, runner, test_names,
+                run_with_thread(test_suite, test_case, run_context, test_names,
                                 try_thread, &threads, &all_success);
             } else {
                 g_warning("This object is not test case!");
@@ -317,14 +325,16 @@ cut_test_suite_run_test_cases (CutTestSuite *test_suite, CutRunner *runner,
         break;
       case SIGSEGV:
         all_success = FALSE;
-        g_signal_emit_by_name(CUT_TEST(test_suite), "crashed", stack_trace);
-        g_free(stack_trace);
+        g_signal_emit_by_name(CUT_TEST(test_suite), "crashed", backtrace);
+        g_free(backtrace);
         break;
       default:
         break;
     }
-    signal(SIGINT, previous_int_handler);
-    signal(SIGSEGV, previous_segv_handler);
+    if (set_int_action)
+        sigaction(SIGINT, &previous_int_action, NULL);
+    if (set_segv_action)
+        sigaction(SIGSEGV, &previous_segv_action, NULL);
 
     g_signal_emit_by_name(CUT_TEST(test_suite), "complete");
 
@@ -334,19 +344,20 @@ cut_test_suite_run_test_cases (CutTestSuite *test_suite, CutRunner *runner,
 }
 
 gboolean
-cut_test_suite_run (CutTestSuite *suite, CutRunner *runner)
+cut_test_suite_run (CutTestSuite *suite, CutRunContext *run_context)
 {
     gchar **test_case_names;
     gchar **test_names;
 
-    test_case_names = cut_runner_get_target_test_case_names(runner);
-    test_names = cut_runner_get_target_test_names(runner);
-    return cut_test_suite_run_with_filter(suite, runner,
-                                          test_case_names, test_names);
+    test_case_names = cut_run_context_get_target_test_case_names(run_context);
+    test_names = cut_run_context_get_target_test_names(run_context);
+    return cut_test_suite_run_with_filter(suite, run_context,
+                                          (const gchar **)test_case_names,
+                                          (const gchar **)test_names);
 }
 
 gboolean
-cut_test_suite_run_test_case (CutTestSuite *suite, CutRunner *runner,
+cut_test_suite_run_test_case (CutTestSuite *suite, CutRunContext *run_context,
                               gchar *test_case_name)
 {
     gchar *test_case_names[] = {NULL, NULL};
@@ -354,28 +365,28 @@ cut_test_suite_run_test_case (CutTestSuite *suite, CutRunner *runner,
     g_return_val_if_fail(CUT_IS_TEST_SUITE(suite), FALSE);
 
     test_case_names[0] = test_case_name;
-    return cut_test_suite_run_with_filter(suite, runner,
-                                          test_case_names, NULL);
+    return cut_test_suite_run_with_filter(suite, run_context,
+                                          (const gchar **)test_case_names, NULL);
 }
 
 gboolean
-cut_test_suite_run_test (CutTestSuite *suite, CutRunner *runner,
+cut_test_suite_run_test (CutTestSuite *suite, CutRunContext *run_context,
                          gchar *test_name)
 {
     GList *test_cases;
-    gchar *test_names[] = {NULL, NULL};
+    const gchar *test_names[] = {NULL, NULL};
 
     g_return_val_if_fail(CUT_IS_TEST_SUITE(suite), FALSE);
 
     test_names[0] = test_name;
     test_cases = cut_test_container_get_children(CUT_TEST_CONTAINER(suite));
-    return cut_test_suite_run_test_cases(suite, runner,
+    return cut_test_suite_run_test_cases(suite, run_context,
                                          test_cases, test_names);
 }
 
 gboolean
 cut_test_suite_run_test_in_test_case (CutTestSuite *suite,
-                                      CutRunner    *runner,
+                                      CutRunContext    *run_context,
                                       gchar        *test_name,
                                       gchar        *test_case_name)
 {
@@ -387,15 +398,16 @@ cut_test_suite_run_test_in_test_case (CutTestSuite *suite,
     test_names[0] = test_name;
     test_case_names[0] = test_case_name;
 
-    return cut_test_suite_run_with_filter(suite, runner,
-                                          test_case_names, test_names);
+    return cut_test_suite_run_with_filter(suite, run_context,
+                                          (const gchar **)test_case_names,
+                                          (const gchar **)test_names);
 }
 
 gboolean
 cut_test_suite_run_with_filter (CutTestSuite *test_suite,
-                                CutRunner   *runner,
-                                gchar **test_case_names,
-                                gchar **test_names)
+                                CutRunContext   *run_context,
+                                const gchar **test_case_names,
+                                const gchar **test_names)
 {
     CutTestContainer *container;
     GList *filtered_test_cases = NULL;
@@ -416,7 +428,7 @@ cut_test_suite_run_with_filter (CutTestSuite *test_suite,
     if (!filtered_test_cases)
         return success;
 
-    success = cut_test_suite_run_test_cases(test_suite, runner,
+    success = cut_test_suite_run_test_cases(test_suite, run_context,
                                             filtered_test_cases, test_names);
     g_list_free(filtered_test_cases);
 
