@@ -27,9 +27,10 @@
 
 #include "cut-test.h"
 #include "cut-test-container.h"
-#include "cut-runner.h"
+#include "cut-run-context.h"
 #include "cut-marshalers.h"
 #include "cut-test-result.h"
+#include "cut-utils.h"
 
 #define CUT_TEST_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), CUT_TYPE_TEST, CutTestPrivate))
 
@@ -37,8 +38,10 @@ typedef struct _CutTestPrivate	CutTestPrivate;
 struct _CutTestPrivate
 {
     gchar *name;
+    gchar *element_name;
     CutTestFunction test_function;
     GTimer *timer;
+    gdouble elapsed;
     GHashTable *attributes;
 };
 
@@ -46,6 +49,7 @@ enum
 {
     PROP_0,
     PROP_NAME,
+    PROP_ELEMENT_NAME,
     PROP_TEST_FUNCTION
 };
 
@@ -78,7 +82,8 @@ static void get_property   (GObject         *object,
                             GValue          *value,
                             GParamSpec      *pspec);
 
-static gdouble      real_get_elapsed  (CutTest  *test);
+static gdouble      get_elapsed  (CutTest  *test);
+static void         set_elapsed  (CutTest  *test, gdouble elapsed);
 
 static void
 cut_test_class_init (CutTestClass *klass)
@@ -92,7 +97,8 @@ cut_test_class_init (CutTestClass *klass)
     gobject_class->set_property = set_property;
     gobject_class->get_property = get_property;
 
-    klass->get_elapsed = real_get_elapsed;
+    klass->get_elapsed = get_elapsed;
+    klass->set_elapsed = set_elapsed;
 
     spec = g_param_spec_string("name",
                                "Test name",
@@ -101,6 +107,13 @@ cut_test_class_init (CutTestClass *klass)
                                G_PARAM_READWRITE);
     g_object_class_install_property(gobject_class, PROP_NAME, spec);
 
+    spec = g_param_spec_string("element-name",
+                               "Element name",
+                               "The element name of the test",
+                               NULL,
+                               G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY);
+    g_object_class_install_property(gobject_class, PROP_ELEMENT_NAME, spec);
+
     spec = g_param_spec_pointer("test-function",
                                 "Test Function",
                                 "The function for test",
@@ -213,6 +226,7 @@ cut_test_init (CutTest *test)
 
     priv->test_function = NULL;
     priv->timer = NULL;
+    priv->elapsed = -1.0;
     priv->attributes = g_hash_table_new_full(g_str_hash, g_str_equal,
                                              g_free, g_free);
 }
@@ -227,6 +241,11 @@ dispose (GObject *object)
         priv->name = NULL;
     }
 
+    if (priv->element_name) {
+        g_free(priv->element_name);
+        priv->element_name = NULL;
+    }
+
     priv->test_function = NULL;
 
     if (priv->timer) {
@@ -254,6 +273,13 @@ set_property (GObject      *object,
       case PROP_NAME:
         cut_test_set_name(CUT_TEST(object), g_value_get_string(value));
         break;
+      case PROP_ELEMENT_NAME:
+        if (priv->element_name) {
+            g_free(priv->element_name);
+            priv->element_name = NULL;
+        }
+        priv->element_name = g_value_dup_string(value);
+        break;
       case PROP_TEST_FUNCTION:
         priv->test_function = g_value_get_pointer(value);
         break;
@@ -275,6 +301,9 @@ get_property (GObject    *object,
       case PROP_NAME:
         g_value_set_string(value, priv->name);
         break;
+      case PROP_ELEMENT_NAME:
+        g_value_set_string(value, priv->element_name);
+        break;
       case PROP_TEST_FUNCTION:
         g_value_set_pointer(value, priv->test_function);
         break;
@@ -288,13 +317,20 @@ CutTest *
 cut_test_new (const gchar *name, CutTestFunction function)
 {
     return g_object_new(CUT_TYPE_TEST,
+                        "element-name", "test",
                         "name", name,
                         "test-function", function,
                         NULL);
 }
 
+CutTest *
+cut_test_new_empty (void)
+{
+    return cut_test_new(NULL, NULL);
+}
+
 gboolean
-cut_test_run (CutTest *test, CutTestContext *test_context, CutRunner *runner)
+cut_test_run (CutTest *test, CutTestContext *test_context, CutRunContext *run_context)
 {
     CutTestPrivate *priv = CUT_TEST_GET_PRIVATE(test);
     gboolean success = TRUE;
@@ -303,7 +339,7 @@ cut_test_run (CutTest *test, CutTestContext *test_context, CutRunner *runner)
     if (!priv->test_function)
         return FALSE;
 
-    cut_runner_prepare_test(runner, test);
+    cut_run_context_prepare_test(run_context, test);
 
     g_signal_emit_by_name(test, "start");
 
@@ -364,10 +400,13 @@ cut_test_get_description (CutTest *test)
 }
 
 static gdouble
-real_get_elapsed (CutTest *test)
+get_elapsed (CutTest *test)
 {
     CutTestPrivate *priv = CUT_TEST_GET_PRIVATE(test);
 
+    if (!(priv->elapsed < 0.0))
+        return priv->elapsed;
+
     if (priv->timer)
         return g_timer_elapsed(priv->timer, NULL);
     else
@@ -380,6 +419,18 @@ cut_test_get_elapsed (CutTest *test)
     return CUT_TEST_GET_CLASS(test)->get_elapsed(test);
 }
 
+static void
+set_elapsed (CutTest *test, gdouble elapsed)
+{
+    CUT_TEST_GET_PRIVATE(test)->elapsed = elapsed;
+}
+
+void
+cut_test_set_elapsed (CutTest *test, gdouble elapsed)
+{
+    return CUT_TEST_GET_CLASS(test)->set_elapsed(test, elapsed);
+}
+
 const gchar *
 cut_test_get_attribute (CutTest *test, const gchar *name)
 {
@@ -394,7 +445,7 @@ cut_test_set_attribute (CutTest *test, const gchar *name, const gchar *value)
                          g_strdup(value));
 }
 
-const GHashTable *
+GHashTable *
 cut_test_get_attributes (CutTest *test)
 {
     return CUT_TEST_GET_PRIVATE(test)->attributes;
@@ -411,6 +462,83 @@ cut_test_stop_timer (CutTest *test)
         g_timer_stop(priv->timer);
 }
 
+gchar *
+cut_test_to_xml (CutTest *test)
+{
+    GString *string;
+
+    string = g_string_new(NULL);
+    cut_test_to_xml_string(test, string, 0);
+    return g_string_free(string, FALSE);
+}
+
+typedef struct _AppendAttributeInfo {
+    GString *string;
+    guint indent;
+} AppendAttributeInfo;
+
+static void
+append_attribute (const gchar *key, const gchar *value,
+                  AppendAttributeInfo *info)
+{
+    if (strcmp(key, "description") == 0)
+        return;
+
+    cut_utils_append_indent(info->string, info->indent);
+    g_string_append(info->string, "<option>\n");
+
+    cut_utils_append_xml_element_with_value(info->string, info->indent + 2,
+                                            "name", key);
+    cut_utils_append_xml_element_with_value(info->string, info->indent + 2,
+                                            "value", value);
+
+    cut_utils_append_indent(info->string, info->indent);
+    g_string_append(info->string, "</option>\n");
+}
+
+void
+cut_test_to_xml_string (CutTest *test, GString *string, guint indent)
+{
+    CutTestPrivate *priv;
+    gchar *escaped, *elapsed;
+    const gchar *description, *name;
+    GHashTable *attributes;
+
+    priv = CUT_TEST_GET_PRIVATE(test);
+
+    escaped = g_markup_escape_text(priv->element_name, -1);
+    cut_utils_append_indent(string, indent);
+    g_string_append_printf(string, "<%s>\n", escaped);
+
+    name = cut_test_get_name(test);
+    if (name)
+        cut_utils_append_xml_element_with_value(string, indent + 2,
+                                                "name", name);
+
+    description = cut_test_get_description(test);
+    if (description)
+        cut_utils_append_xml_element_with_value(string, indent + 2,
+                                                "description", description);
+
+    elapsed = g_strdup_printf("%f", cut_test_get_elapsed(test));
+    cut_utils_append_xml_element_with_value(string, indent + 2,
+                                            "elapsed", elapsed);
+    g_free(elapsed);
+
+    attributes = cut_test_get_attributes(test);
+    if (attributes) {
+        AppendAttributeInfo info;
+
+        info.string = string;
+        info.indent = indent + 2;
+        g_hash_table_foreach(attributes, (GHFunc)append_attribute, &info);
+    }
+
+    cut_utils_append_indent(string, indent);
+    g_string_append_printf(string, "</%s>\n", escaped);
+    g_free(escaped);
+}
+
 /*
 vi:ts=4:nowrap:ai:expandtab:sw=4
 */
