@@ -2,20 +2,18 @@
 /*
  *  Copyright (C) 2007  Kouhei Sutou <kou@cozmixng.org>
  *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Lesser General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
+ *  This library is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU Lesser General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
  *
  *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
- *  License along with this program; if not, write to the
- *  Free Software Foundation, Inc., 59 Temple Place, Suite 330,
- *  Boston, MA  02111-1307  USA
+ *  You should have received a copy of the GNU Lesser General Public License
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -38,7 +36,7 @@ cut_verbose_level_error_quark (void)
 CutVerboseLevel
 cut_verbose_level_parse (const gchar *name, GError **error)
 {
-    CutVerboseLevel level = CUT_VERBOSE_LEVEL_NORMAL;
+    CutVerboseLevel level = CUT_VERBOSE_LEVEL_INVALID;
 
     if (name == NULL) {
         level = CUT_VERBOSE_LEVEL_NORMAL;
@@ -52,16 +50,17 @@ cut_verbose_level_parse (const gchar *name, GError **error)
                g_utf8_collate(name, "verbose") == 0) {
         level = CUT_VERBOSE_LEVEL_VERBOSE;
     } else {
-        if (error)
+        if (error) {
             g_set_error(error,
                         CUT_VERBOSE_LEVEL_ERROR,
                         CUT_VERBOSE_LEVEL_ERROR_BAD_VALUE,
                         "Invalid verbose level name: %s", name);
+        }
     }
 
     return level;
 }
 
 /*
-vi:nowrap:ai:expandtab:sw=4
+vi:ts=4:nowrap:ai:expandtab:sw=4
 */
