@@ -10,6 +10,8 @@ export CUT_UI_MODULE_DIR=$BASE_DIR/../../cutter/module/ui/.libs
 export CUT_UI_FACTORY_MODULE_DIR=$BASE_DIR/../../cutter/module/ui/.libs
 export CUT_REPORT_MODULE_DIR=$BASE_DIR/../../cutter/module/report/.libs
 export CUT_REPORT_FACTORY_MODULE_DIR=$BASE_DIR/../../cutter/module/report/.libs
+export CUT_STREAMER_MODULE_DIR=$BASE_DIR/../../cutter/module/streamer/.libs
+export CUT_STREAMER_FACTORY_MODULE_DIR=$BASE_DIR/../../cutter/module/streamer/.libs
 
 CUTTER=$BASE_DIR/../../cutter/cutter
 if test x"$CUTTER_DEBUG" = x"yes"; then
