@@ -19,8 +19,10 @@ export CUT_UI_MODULE_DIR=$BASE_DIR/../cutter/module/ui/.libs
 export CUT_UI_FACTORY_MODULE_DIR=$BASE_DIR/../cutter/module/ui/.libs
 export CUT_REPORT_MODULE_DIR=$BASE_DIR/../cutter/module/report/.libs
 export CUT_REPORT_FACTORY_MODULE_DIR=$BASE_DIR/../cutter/module/report/.libs
+export CUT_STREAMER_MODULE_DIR=$BASE_DIR/../cutter/module/streamer/.libs
+export CUT_STREAMER_FACTORY_MODULE_DIR=$BASE_DIR/../cutter/module/streamer/.libs
 
-CUTTER_ARGS="-s $BASE_DIR"
+CUTTER_ARGS="-s $BASE_DIR --exclude-dir=pipeline_test_dir"
 if test x"$USE_GTK" = x"yes"; then
     CUTTER_ARGS="-u gtk $CUTTER_ARGS"
 fi
