@@ -3,7 +3,6 @@
 #include "cut-test-result.h"
 #include "cut-loader.h"
 #include "cut-utils.h"
-#include "cut-runner.h"
 #include "cuttest-utils.h"
 #include "cuttest-assertions.h"
 
@@ -68,13 +67,13 @@ test_get_bug_id (void)
 {
     CutTestContainer *container;
     GList *tests;
-    gchar *filter[] = {"/test_get_bug_id/", NULL};
+    const gchar *filter[] = {"/test_get_bug_id/", NULL};
 
     test_case = cut_loader_load_test_case(test_loader);
     cut_assert(test_case);
 
     container = CUT_TEST_CONTAINER(test_case);
-    tests = (GList *)cut_test_container_filter_children(container, filter);
+    tests = cut_test_container_filter_children(container, filter);
     cut_assert(tests);
 
     cut_assert(1, g_list_length(tests));
@@ -86,13 +85,13 @@ test_get_attribute (void)
 {
     CutTestContainer *container;
     GList *tests;
-    gchar *filter[] = {"/test_attribute/", NULL};
+    const gchar *filter[] = {"/test_attribute/", NULL};
 
     test_case = cut_loader_load_test_case(test_loader);
     cut_assert(test_case);
 
     container = CUT_TEST_CONTAINER(test_case);
-    tests = (GList *)cut_test_container_filter_children(container, filter);
+    tests = cut_test_container_filter_children(container, filter);
     cut_assert(tests);
 
     cut_assert(1, g_list_length(tests));
@@ -107,13 +106,13 @@ test_get_description (void)
 {
     CutTestContainer *container;
     GList *tests;
-    gchar *filter[] = {"/test_description/", NULL};
+    const gchar *filter[] = {"/test_description/", NULL};
 
     test_case = cut_loader_load_test_case(test_loader);
     cut_assert(test_case);
 
     container = CUT_TEST_CONTAINER(test_case);
-    tests = (GList *)cut_test_container_filter_children(container, filter);
+    tests = cut_test_container_filter_children(container, filter);
     cut_assert(tests);
 
     cut_assert(1, g_list_length(tests));
