@@ -1,6 +1,6 @@
 #include <cutter.h>
 #include <cutter/cut-test.h>
-#include <cutter/cut-runner.h>
+#include <cutter/cut-test-runner.h>
 
 void test_get_name(void);
 void test_get_description(void);
@@ -15,8 +15,9 @@ void test_pending_signal(void);
 void test_notification_signal(void);
 void test_omission_signal(void);
 void test_test_function (void);
+void test_set_elapsed(void);
 
-static CutRunner *runner;
+static CutRunContext *run_context;
 static CutTest *test_object;
 static gboolean run_test_flag = FALSE;
 static gint n_start_signal = 0;
@@ -82,7 +83,7 @@ setup (void)
     n_pass_assertion_signal = 0;
     n_omission_signal = 0;
 
-    runner = cut_runner_new();
+    run_context = CUT_RUN_CONTEXT(cut_test_runner_new());
 
     test_object = cut_test_new("dummy-test", dummy_test_function);
 }
@@ -91,7 +92,7 @@ void
 teardown (void)
 {
     g_object_unref(test_object);
-    g_object_unref(runner);
+    g_object_unref(run_context);
 }
 
 static void
@@ -152,7 +153,7 @@ run (CutTest *test)
     test_context = cut_test_context_new(NULL, NULL, test);
     original_test_context = get_current_test_context();
     set_current_test_context(test_context);
-    success = cut_test_run(test, test_context, runner);
+    success = cut_test_run(test, test_context, run_context);
     set_current_test_context(original_test_context);
 
     g_object_unref(test_context);
@@ -315,6 +316,16 @@ test_pass_assertion_signal (void)
     cut_assert_equal_int(3, n_pass_assertion_signal);
 }
 
+void
+test_set_elapsed (void)
+{
+    cut_assert_equal_double(0.0, 0.1, cut_test_get_elapsed(test_object));
+    cut_test_set_elapsed(test_object, 3.0);
+    cut_assert_equal_double(3.0, 0.1, cut_test_get_elapsed(test_object));
+    cut_test_set_elapsed(test_object, -1.0);
+    cut_assert_equal_double(0.0, 0.1, cut_test_get_elapsed(test_object));
+}
+
 /*
 vi:ts=4:nowrap:ai:expandtab:sw=4
 */
