@@ -6,12 +6,18 @@
 
 #include <glib.h>
 
+#ifdef HAVE_GTK
+#  include <gtk/gtk.h>
+#endif
+
 enum {
     ENV_LANG,
     ENV_CUT_UI_MODULE_DIR,
     ENV_CUT_UI_FACTORY_MODULE_DIR,
     ENV_CUT_REPORT_MODULE_DIR,
     ENV_CUT_REPORT_FACTORY_MODULE_DIR,
+    ENV_CUT_STREAMER_MODULE_DIR,
+    ENV_CUT_STREAMER_FACTORY_MODULE_DIR,
     ENV_LAST
 };
 
@@ -28,16 +34,26 @@ static gchar *stdout_string = NULL;
 static gchar *stderr_string = NULL;
 static gint exit_status = 0;
 
-static const gchar help_message[] =
+static const gchar *help_message;
+
+void
+setup (void)
+{
+    stdout_string = NULL;
+    stderr_string = NULL;
+    exit_status = 0;
+
+    help_message = cut_take_printf(
         "Usage:\n"
-        "  lt-cutter [OPTION...] TEST_DIRECTORY\n"
+        "  %s [OPTION...] TEST_DIRECTORY\n"
         "\n"
         "Help Options:\n"
         "  -?, --help                                      Show help options\n"
         "  --help-all                                      Show all help options\n"
+        "  --help-streamer                                 Show streamer options\n"
         "  --help-report                                   Show report options\n"
         "  --help-ui                                       Show UI options\n"
-        "  --help-ui-console                               Show console UI options\n"
+        "  --help-console-ui                               Show console UI options\n"
         "\n"
         "Application Options:\n"
         "  --version                                       Show version\n"
@@ -46,14 +62,10 @@ static const gchar help_message[] =
         "  -t, --test-case=TEST_CASE_NAME                  Specify test cases\n"
         "  -m, --multi-thread                              Run test cases with multi-thread\n"
         "  --test-case-order=[none|name|name-desc]         Sort test case by. Default is 'none'.\n"
-        "\n";
-
-void
-setup (void)
-{
-    stdout_string = NULL;
-    stderr_string = NULL;
-    exit_status = 0;
+        "  --exclude-file=FILE_NAME                        Skip files\n"
+        "  --exclude-dir=DIRECTORY_NAME                    Skip directories\n"
+        "\n",
+        g_get_prgname());
 }
 
 void
@@ -88,6 +100,8 @@ run_cutter (const gchar *options)
     SET_ENV(CUT_UI_FACTORY_MODULE_DIR);
     SET_ENV(CUT_REPORT_MODULE_DIR);
     SET_ENV(CUT_REPORT_FACTORY_MODULE_DIR);
+    SET_ENV(CUT_STREAMER_MODULE_DIR);
+    SET_ENV(CUT_STREAMER_FACTORY_MODULE_DIR);
 #undef SET_ENV
 
     envp[ENV_LAST] = NULL;
@@ -142,41 +156,53 @@ test_no_option (void)
 void
 test_help_all (void)
 {
-    const gchar expected[] =
+    const gchar *help_all_message;
+
+    help_all_message = cut_take_printf(
         "Usage:\n"
-        "  lt-cutter [OPTION...] TEST_DIRECTORY\n"
+        "  %s [OPTION...] TEST_DIRECTORY\n"
         "\n"
         "Help Options:\n"
         "  -?, --help                                      Show help options\n"
         "  --help-all                                      Show all help options\n"
+        "  --help-streamer                                 Show streamer options\n"
         "  --help-report                                   Show report options\n"
         "  --help-ui                                       Show UI options\n"
-        "  --help-ui-console                               Show console UI options\n"
-#if HAVE_GTK
+        "  --help-xml-streamer                             Show XML streamer options\n"
+        "  --help-console-ui                               Show console UI options\n"
+#ifdef HAVE_GTK
         "  --help-gtk                                      Show GTK+ Options\n"
 #endif
+        "\n"
+        "Streamer Options\n"
+        "  --streamer=[xml]                                Specify streamer\n"
         "\n"
         "Report Options\n"
         "  --pdf-report=FILE                               Set filename of pdf report\n"
         "  --xml-report=FILE                               Set filename of xml report\n"
         "\n"
         "UI Options\n"
-#if HAVE_GTK
+#ifdef HAVE_GTK
         "  -u, --ui=[console|gtk]                          Specify UI\n"
 #else
         "  -u, --ui=[console]                              Specify UI\n"
 #endif
+        "\n"
+        "XML Streamer Options\n"
+        "  --stream-fd=FILE_DESCRIPTOR                     Stream to FILE_DESCRIPTOR (default: stdout)\n"
         "\n"
         "Console UI Options\n"
         "  -v, --verbose=[s|silent|n|normal|v|verbose]     Set verbose level\n"
         "  -c, --color=[yes|true|no|false|auto]            Output log with colors\n"
         "\n"
-#if HAVE_GTK
+#ifdef HAVE_GTK
         "GTK+ Options\n"
         "  --class=CLASS                                   Program class as used by the window manager\n"
         "  --gtk-name=NAME                                 Program name as used by the window manager\n"
         "  --screen=SCREEN                                 X screen to use\n"
+#  ifdef GDK_WINDOWING_X11
         "  --sync                                          Make X calls synchronous\n"
+#  endif
         "  --gtk-module=MODULES                            Load additional GTK+ modules\n"
         "  --g-fatal-warnings                              Make all warnings fatal\n"
         "\n"
@@ -188,21 +214,24 @@ test_help_all (void)
         "  -t, --test-case=TEST_CASE_NAME                  Specify test cases\n"
         "  -m, --multi-thread                              Run test cases with multi-thread\n"
         "  --test-case-order=[none|name|name-desc]         Sort test case by. Default is 'none'.\n"
-#if HAVE_GTK
+        "  --exclude-file=FILE_NAME                        Skip files\n"
+        "  --exclude-dir=DIRECTORY_NAME                    Skip directories\n"
+#ifdef HAVE_GTK
         "  --display=DISPLAY                               X display to use\n"
 #endif
-        "\n";
+        "\n",
+        g_get_prgname());
 
     cut_assert(run_cutter("--help-all"));
-    cut_assert_equal_int(exit_status, 0);
-    cut_assert_equal_string(expected, stdout_string);
+    cut_assert_equal_int(0, exit_status);
+    cut_assert_equal_string(help_all_message, stdout_string);
 }
 
 void
 test_invalid_option (void)
 {
     cut_assert(run_cutter("--XXXX"));
-    cut_assert_equal_int(exit_status, 256);
+    cut_assert_equal_int(256, exit_status);
     cut_assert_equal_string("Unknown option --XXXX\n", stdout_string);
 }
 
@@ -210,7 +239,7 @@ void
 test_invalid_color_option (void)
 {
     cut_assert(run_cutter("--color=XXX"));
-    cut_assert_equal_int(exit_status, 256);
+    cut_assert_equal_int(256, exit_status);
     cut_assert_equal_string("Invalid color value: XXX\n", stdout_string);
 }
 
@@ -218,7 +247,7 @@ void
 test_invalid_order_option (void)
 {
     cut_assert(run_cutter("--test-case-order=XXX"));
-    cut_assert_equal_int(exit_status, 256);
+    cut_assert_equal_int(256, exit_status);
     cut_assert_equal_string("Invalid test case order value: XXX\n", stdout_string);
 }
 
@@ -226,7 +255,7 @@ void
 test_invalid_verbose_option (void)
 {
     cut_assert(run_cutter("--verbose=XXX"));
-    cut_assert_equal_int(exit_status, 256);
+    cut_assert_equal_int(256, exit_status);
     cut_assert_equal_string("Invalid verbose level name: XXX\n", stdout_string);
 }
 
